summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
authorAndreas Huber <andih@google.com>2012-10-01 11:22:05 -0700
committerAndreas Huber <andih@google.com>2012-10-01 11:24:04 -0700
commit0e1d71641624c641a0a1abe4098943f5a42c6f94 (patch)
tree676b461c207b032cb45f6e35cd4a4dc225c4fe7c /include
parent6360758ce2d171169d2a21e30266547ee4ac0fec (diff)
downloadframeworks_av-0e1d71641624c641a0a1abe4098943f5a42c6f94.zip
frameworks_av-0e1d71641624c641a0a1abe4098943f5a42c6f94.tar.gz
frameworks_av-0e1d71641624c641a0a1abe4098943f5a42c6f94.tar.bz2
Remove double negatives from SurfaceMediaSource
ensure mStarted actually reflects the state of SurfaceMediaSource Change-Id: I92557896993ad8da23fe6940e997402ad63b8cbc related-to-bug: 7258622
Diffstat (limited to 'include')
-rw-r--r--include/media/stagefright/SurfaceMediaSource.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/media/stagefright/SurfaceMediaSource.h b/include/media/stagefright/SurfaceMediaSource.h
index f60a535..82e5965 100644
--- a/include/media/stagefright/SurfaceMediaSource.h
+++ b/include/media/stagefright/SurfaceMediaSource.h
@@ -193,8 +193,8 @@ private:
// Set to a default of 30 fps if not specified by the client side
int32_t mFrameRate;
- // mStopped is a flag to check if the recording is going on
- bool mStopped;
+ // mStarted is a flag to check if the recording is going on
+ bool mStarted;
// mNumFramesReceived indicates the number of frames recieved from
// the client side